import QtQuick 2.4
import Trogl 1.0

Item {
    id: _Ctrl
    width: uiSettings.slsh
    height: uiSettings.slsh
    visible: false
    property int mode: 0 //0-stop
                         //1 - up
                         //2 - down
                         //3 - left
                         //4 - right

    signal newMode(int nMode);
    property var skin: Skin

    onSkinChanged: bg.requestPaint()

    onModeChanged: {
        switch (mode) {
            case 0://stop
                btn.x = (_Ctrl.width - btn.width)/2
                btn.y = (_Ctrl.height - btn.height)/2
                break;
            case 1://up
                btn.x = (_Ctrl.width - btn.width)/2
                btn.y = uiSettings.sld
                break;
            case 2://down
                btn.x = (_Ctrl.width - btn.width)/2
                btn.y = _Ctrl.height - btn.height - uiSettings.sld
                break;
            case 3://left
                btn.x = uiSettings.sld
                btn.y = (_Ctrl.height - btn.height)/2
                break;
            case 4://right
                btn.x = _Ctrl.width - btn.width - uiSettings.sld
                btn.y = (_Ctrl.height - btn.height)/2
                break;
        }
        newMode(mode);
    }

    Canvas {
        id: bg
        anchors.fill: parent

        onPaint: {
            var ctx = getContext("2d");
            var slsh = uiSettings.slsh
            var sld = uiSettings.sld
            var slbw = uiSettings.slbw
            var tmpMin = (slsh - slbw)/2
            var tmpMax = (slsh + slbw)/2

            ctx.fillStyle = Skin.shutterCtrlBackground
            ctx.lineWidth = uiSettings.slcw;
            ctx.strokeStyle = Skin.shutterCtrlBorder

            ctx.beginPath();
            ctx.moveTo(0, tmpMin + sld);
            ctx.quadraticCurveTo(0, tmpMin - sld, sld*2, tmpMin - sld)
            ctx.lineTo(tmpMin - sld, tmpMin - sld)
            ctx.lineTo(tmpMin - sld, 2*sld)
            ctx.quadraticCurveTo(tmpMin - sld, 0, tmpMin + sld, 0)
            ctx.lineTo(tmpMax - sld, 0)
            ctx.quadraticCurveTo(tmpMax + sld, 0, tmpMax + sld, 2*sld)
            ctx.lineTo(tmpMax + sld, tmpMin - sld)
            ctx.lineTo(width - 2*sld, tmpMin - sld)
            ctx.quadraticCurveTo(width, tmpMin - sld, width, tmpMin + sld)
            ctx.lineTo(width, tmpMax - sld)
            ctx.quadraticCurveTo(width, tmpMax + sld, width - 2*sld, tmpMax + sld)
            ctx.lineTo(tmpMax + sld, tmpMax + sld)
            ctx.lineTo(tmpMax + sld, height - 2*sld)
            ctx.quadraticCurveTo(tmpMax + sld, height, tmpMax - sld, height)
            ctx.lineTo(tmpMin + sld, height)
            ctx.quadraticCurveTo(tmpMin - sld, height, tmpMin - sld, height - 2*sld)
            ctx.lineTo(tmpMin - sld, tmpMax + sld)
            ctx.lineTo(2*sld, tmpMax + sld)
            ctx.quadraticCurveTo(0, tmpMax + sld, 0, tmpMax - sld)
            ctx.closePath()
            ctx.fill();

            ctx.beginPath();
            ctx.moveTo(sld, tmpMin + sld);
            ctx.quadraticCurveTo(sld, tmpMin, 2*sld, tmpMin)
            ctx.lineTo(tmpMin - sld, tmpMin);
            ctx.quadraticCurveTo(tmpMin, tmpMin, tmpMin, tmpMin - sld)
            ctx.lineTo(tmpMin, 2*sld);
            ctx.quadraticCurveTo(tmpMin, sld, tmpMin + sld, sld)
            ctx.lineTo(tmpMax - sld, sld);
            ctx.quadraticCurveTo(tmpMax, sld, tmpMax, 2*sld)
            ctx.lineTo(tmpMax + sld - sld , tmpMin -sld);
            ctx.quadraticCurveTo(tmpMax, tmpMin, tmpMax + sld, tmpMin)
            ctx.lineTo(width - 2*sld,  tmpMin);
            ctx.quadraticCurveTo(width - sld,  tmpMin, width - sld,  tmpMin + sld)
            ctx.lineTo(width - sld,  tmpMax - sld);
            ctx.quadraticCurveTo(width - sld,  tmpMax, width - 2*sld,  tmpMax)
            ctx.lineTo(tmpMax + sld,  tmpMax);
            ctx.quadraticCurveTo(tmpMax,  tmpMax, tmpMax,  tmpMax + sld)
            ctx.lineTo(tmpMax,  height - 2*sld);
            ctx.quadraticCurveTo(tmpMax,  height - sld, tmpMax - sld,  height - sld)
            ctx.lineTo(tmpMin + sld,  height - sld);
            ctx.quadraticCurveTo(tmpMin,  height - sld, tmpMin,  height - 2*sld)
            ctx.lineTo(tmpMin,  tmpMax + sld);
            ctx.quadraticCurveTo(tmpMin,  tmpMax, tmpMin - sld,  tmpMax)
            ctx.lineTo(sld*2,  tmpMax);
            ctx.quadraticCurveTo(sld,  tmpMax, sld,  tmpMax - sld)
            ctx.closePath();
            ctx.stroke();

        }
    }
    Image {
        source: "qrc:/Mechanics/shutters_arrow_up.svg"
        x: (bg.width - width)/2
        y: uiSettings.sld*2
        width: height*15/19
        height: uiSettings.sld*2
        sourceSize.width: width
        sourceSize.height: height
        fillMode: Image.PreserveAspectFit
    }
    Image {
        source: "qrc:/Mechanics/shutters_arrow_down.svg"
        x: (bg.width - width)/2
        y: bg.height - uiSettings.sld*2 - height
        width: height*15/19
        height: uiSettings.sld*2
        sourceSize.width: width
        sourceSize.height: height
        fillMode: Image.PreserveAspectFit
    }
    Image {
        source: "qrc:/Mechanics/shutters_arrow_left.svg"
        x: uiSettings.sld*2
        y: (bg.height - height)/2
        width: height/2
        height: btn.height*0.5
        sourceSize.width: width
        sourceSize.height: height
        fillMode: Image.PreserveAspectFit
    }
    Image {
        source: "qrc:/Mechanics/shutters_arrow_right.svg"
        x: bg.width - uiSettings.sld*2 - width
        y: (bg.height - height)/2
        width: height/2
        height: btn.height*0.5
        sourceSize.width: width
        sourceSize.height: height
        fillMode: Image.PreserveAspectFit
    }
        Rectangle {
        id: btn
        x: (_Ctrl.width - btn.width)/2
        y: (_Ctrl.height - btn.height)/2
        width: uiSettings.slbw
        height: uiSettings.slbw

        radius: uiSettings.slrb
        gradient: Skin.shutterCtrlThumbBackground

        Image {
            source: "qrc:/Mechanics/shutters_pic.svg"
            anchors.centerIn: parent
            width: parent.width*0.3
            height: parent.height*0.5
            sourceSize.width: width
            sourceSize.height: height
            fillMode: Image.PreserveAspectFit
        }
    }

    function open(mouseX, mouseY) {
        x = mouseX - _Ctrl.width/2
        y = mouseY - _Ctrl.height/2
        visible = true
    }

    function updatePos(pt) {
        if(Math.abs(pt.x - _Ctrl.width/2) < btn.width/2 &&
           Math.abs(pt.y - _Ctrl.height/2) < btn.height/2)
            mode = 0;
        else
        if(Math.abs(pt.x - _Ctrl.width/2) < btn.width/2)
        {
            if(pt.y < btn.height)
                mode = 1
            else
            if(pt.y > _Ctrl.height - btn.height)
                mode = 2
        }
        else
        if(Math.abs(pt.y - _Ctrl.height/2) < btn.height/2)
        {
            if(pt.x < btn.width)
                mode = 3
            else
            if(pt.x > _Ctrl.width - btn.width)
                mode = 4

        }
    }

    function released(pt)
    {
        visible = false
    }
    function moved(pt)
    {
        pt.x -= _Ctrl.x
        pt.y -= _Ctrl.y
        updatePos(pt)
    }

}

