import QtQuick 2.4
import "../TroglControls"
import ".."

Item {
    id: projectTab
    objectName: "projectSettings"
    clip: true

    function projectSettingsChanged() {
        tab.item.saveSettings();
    }
    function navClose() {
        if(prjList.currentIndex === 3)
            return tab.children[0].navClose()
        else
            return false
    }

    Component.onCompleted: {
        projectTypeList.append({'caption': Langpack.applicationProjectLoadingTypeEmbedded,
                                'prjType': 'embedded',
                                'source': 'qrc:/Preferences/ProjEmbedded.qml'})
        projectTypeList.append({'caption': Langpack.applicationProjectLoadingTypeServer,
                                'prjType': 'server',
                                'source': 'qrc:/Preferences/ProjServer.qml'})
        projectTypeList.append({'caption': Langpack.applicationProjectLoadingTypeCloud,
                                'prjType': 'cloud',
                                'source': 'qrc:/Preferences/ProjCloud.qml'})
        if(!Global.ios)
            projectTypeList.append({'caption': Langpack.applicationProjectLoadingTypeFile,
                                    'prjType': 'file',
                                    'source': 'qrc:/Preferences/ProjFile.qml'})

        switch(Global.projectType()){
            case 'embedded':prjList.currentIndex = 0;break;
            case 'server':prjList.currentIndex = 1;break;
            case 'cloud':prjList.currentIndex = 2;break;
            case 'file':prjList.currentIndex = 3;break;
        }

    }

    ListModel {
        id: projectTypeList
    }

    Row {
        anchors.fill: parent
        Item {
           width: parent.width*2/3
           height: parent.height

           Loader {
               id: tab
               anchors.fill: parent
               anchors.rightMargin: uiSettings.md
               source: projectTypeList.get(prjList.currentIndex).source
           }

           Button_s1 {
               anchors.left: parent.left
               anchors.bottom: parent.bottom
               width: uiSettings.b*4
               height: uiSettings.b
               text.text: Langpack.barPreferencesTabProjectButtonLoad

               onClicked: projectSettingsChanged()
           }
        }
        Rectangle {
           id: divider
           height: parent.height
           width: uiSettings.sf/2
           color: Skin.preferencesBarSectionDivider
        }
        Item{
            width: parent.width/3
            height: parent.height

            ListView {
                id: prjList
                anchors.leftMargin: uiSettings.md
                anchors.fill: parent
                model: projectTypeList
                //interactive: false

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        var ind = prjList.indexAt(mouseX, mouseY);
                        if(ind !== -1)
                            prjList.currentIndex = ind;
                    }
                }

                highlight: Rectangle {
                    height: uiSettings.b
                    width: parent.width
                    color: Skin.preferencesBarSelectedTabName
                }
                delegate: Item
                {
                    clip: true
                    height: uiSettings.b
                    width: parent.width

                    Text {
                        text: caption
                        anchors.left: parent.left
                        anchors.leftMargin: uiSettings.md/2
                        anchors.verticalCenter: parent.verticalCenter
                        font.family: "Ubuntu"
                        font.bold: true
                        font.pointSize: uiSettings.btm
                        color: Skin.preferencesBarTabName
                    }
                }
            }
        }
}
}

