import QtQuick 2.0
import Trogl 1.0
import "../"
import "CameraViewerControls"
import QtGraphicalEffects 1.0
import QtQuick.Window 2.2

EngineryLegend
{
    id: _root
    height: Screen.desktopAvailableHeight/4
    property Item ctrlsContainer: ctrls
    property var locCameras: []
    property int spacing: 20
    property int decorHeight: uiSettings.sf
    property bool forseStop: false
    property TronProject proj: project
    clip: true
    property CameraViewerBar camViewBar: null
    anchors.bottom: parent.bottom
    anchors.left: parent.left
    anchors.leftMargin: ui.c*4+ui.i*3// handlingSideBar.stateWidth(3) + uiSettings.tml*2
    anchors.right: parent.right
    anchors.rightMargin: ui.c+ui.i
    opacity: project?project.navOpacity:1.0

    onForseStopChanged: {
        if(forseStop)
            pause()
        else
            resume()
    }

    onOpacityChanged: {
        clearCams()
        if(opacity === 1.0)
            open()
    }

    function open()
    {
        clearCams()
        var cams = []
        for(var i=0; i<engGroup.controls.length; i++)
            if(engGroup.controls[i].objectName === "CameraControl")
                cams.push(engGroup.controls[i])
        addCameras(cams)
    }

    Component.onCompleted: {
        mnemo.setWireframe(true)
    }

    Component.onDestruction: {
        mnemo.setWireframe(false)
        clearCams()
    }

    onProjChanged: {
        mnemo.setWireframe(true)
    }

    NumberAnimation {
        id: _ani
        target: ctrls
        properties: "x"
        duration: 150
        from: ctrls.x

        function starrt() {
            if(from != to)
                start()
            else
            {
                updateVis()
            }
        }

        onRunningChanged: {
            if(!running)
                _root.play()
        }
    }

    Component {
        id: camDelegate
        CameraRibbonView {
            height: _root.height
        }
    }

    Item {
        id: ctrls
        objectName: "ctrls"
        onXChanged: updateVis()
    }
    MouseArea {
        id: ma
        anchors.fill: parent
        property int mx: 0
        property int cx: 0
        property bool doClick: false
        enabled: (!_ani.running)
        onPressed: {
            cx = ctrls.x
            mx = mouseX
            doClick = true
        }
        onMouseXChanged: {
            if(Math.abs(mx - mouseX) > 20)
                doClick = false
            if(ctrls.width > _root.width)
            {
                var targetX = cx + mouseX - mx
                if(targetX >= spacing)
                    ctrls.x = spacing + Math.pow(targetX - spacing, 0.8)
                else
                if(targetX + ctrls.width <= _root.width-spacing)
                {
                    var dx = (_root.width -  spacing) - (targetX + ctrls.width)
                    ctrls.x =  _root.width -  spacing - ctrls.width - Math.pow(dx, 0.8)
                }
                else
                    ctrls.x = targetX
            }
            mnemo.repaint()
        }
        onReleased: {
            var targetX = 0

            if(ctrls.width < _root.width)
                targetX = (_root.width - ctrls.width)/2
            else
            {
                var playerWidth = (_root.height - decorHeight*2)*16/9
                var nVisPlayers = Math.floor((_root.width/(playerWidth + _root.spacing)))
                var visWidth = nVisPlayers * playerWidth + _root.spacing*(nVisPlayers+1)
                var dx = (_root.width - visWidth)*0.5

                var fvC = null//first visible control
                var lvC = null//last visible control
                var pCtrl = null
                for(var nCtrl in ctrls.children)
                {
                    pCtrl = ctrls.children[nCtrl]
                    if((fvC === null) && (pCtrl.x + pCtrl.width + ctrls.x > 0))
                        fvC = pCtrl
                    if(pCtrl.x + ctrls.x < _root.width)
                        lvC = pCtrl
                }
                if(mouseX < mx) {
                    targetX = dx - fvC.x - fvC.width
                }
                else {
                    targetX = _root.width - dx - lvC.x
                }

            }

            _ani.to = cropCtrlsX(targetX)
            _ani.starrt()
        }
        onClicked: {
            if(!doClick) return;
            var nCtrl, nSelectedCtrl = -1, pCtrl = null

            for(nCtrl in ctrls.children) {
                pCtrl = ctrls.children[nCtrl]
                if(ctrls.x + pCtrl.x < mouseX && (ctrls.x + pCtrl.x + pCtrl.width > mouseX ))
                {
                    nSelectedCtrl = nCtrl;
                    break;
                }
            }
            if(nSelectedCtrl >= 0) {
                var component = Qt.createComponent("../CameraViewerBar.qml");
                camViewBar = component.createObject(dynBarsContainer);
                camViewBar.closed.connect(camViewBarClosed)

                for(nCtrl in ctrls.children)
                {
                    pCtrl = ctrls.children[nCtrl];
                    camViewBar.addCam(pCtrl.camName, pCtrl.url, pCtrl.codec)
                }

                camViewBar.current = nSelectedCtrl
                camViewBar.open()
                pause()
            }
        }
    }

    function camViewBarClosed() {
        camViewBar.destroy()
        resume()
    }

    function cropCtrlsX(newX) {
        if(_root.width > ctrls.width)
            return (_root.width - ctrls.width)*0.5

        var newX1 = Math.min(newX, spacing)
        newX1 = Math.max(newX1, _root.width - ctrls.width - spacing)
        return newX1
    }

    function updateVis() {
        var ctrl = null
        var v1 = 0
        for(var i in ctrls.children)
        {
            ctrl = ctrls.children[i]
            if((ctrls.x + ctrl.x < 2*spacing))
            {
                v1 = ctrl.x + ctrls.x
                ctrl.p0 = - v1/ctrl.width
                ctrl.p1 = (2*spacing - v1)/ctrl.width
                ctrl.p2 = 1.0
                ctrl.c0 = "#00000000"
                ctrl.c1 = "#FF000000"
                ctrl.c2 = "#FF000000"
                ctrl.cp0 = "#00ff86ac"
                ctrl.cp1 = "#FFff86ac"
                ctrl.cp2 = "#FFff86ac"
            }
            else
            if((ctrls.x + ctrl.x + ctrl.width > _root.width - 2*spacing))
            {
                v1 = _root.width - ctrl.x - ctrls.x;
                ctrl.p0 = 0.0
                ctrl.p1 = (v1 - 2*spacing)/(ctrl.width)
                ctrl.p2 = v1/ctrl.width
                ctrl.c0 = "#FF000000"
                ctrl.c1 = "#FF000000"
                ctrl.c2 = "#00000000"
                ctrl.cp0 = "#FFff86ac"
                ctrl.cp1 = "#FFff86ac"
                ctrl.cp2 = "#00ff86ac"
            }
            else
            {
                ctrl.c0 = "black"
                ctrl.c1 = "black"
                ctrl.c2 = "black"
                ctrl.cp0 = "#FFff86ac"
                ctrl.cp1 = "#FFff86ac"
                ctrl.cp2 = "#FFff86ac"
            }
        }
        if(ctrls.width < _root.width)
            ctrls.x = (_root.width - ctrls.width)/2
        mnemo.repaint()
    }

    function updated() {
        updateCtrls()
        updateVis()
        play();
    }

    function compare(a, b) {
        var a_pos = mnemo.labelToScreen(a.mdlId(), a.ctrlId())
        var b_pos = mnemo.labelToScreen(b.mdlId(), b.ctrlId())
        if (a_pos.x < b_pos.x)
          return -1;
        if (a_pos.x > b_pos.x)
          return 1;
        return 0;
    }

    function addCameras(cameras) {
        locCameras = []
        var i, cLabelPos
        for(i in cameras)
        {
            cLabelPos = mnemo.labelToScreen(cameras[i].mdlId(), cameras[i].ctrlId())
            if(mnemo.contains(Qt.point(cLabelPos.x, cLabelPos.y)))
                locCameras.push(cameras[i])
        }
        locCameras.sort(compare)
        for(i in locCameras)
        {
            camDelegate.createObject(ctrls, {"camName": locCameras[i].object.name,
                                             "url": locCameras[i].url,
                                             "codec": locCameras[i].codec,
                                             "mdlId": locCameras[i].mdlId(),
                                             "ctrlId": locCameras[i].ctrlId()})
        }
        updated()
    }
    function clearCams()
    {
        if(ctrls.children.length > 0)
        {
            for(var i=ctrls.children.length-1; i>=0; i--)
                ctrls.children[i].destroy();
            ctrls.children = []
        }
    }


    function updateCtrls()
    {
        var dx = _root.spacing;
        var pCtrl = null
        for(var i in ctrls.children)
        {
            pCtrl = ctrls.children[i]
            pCtrl.x = dx
            dx += pCtrl.width + _root.spacing
        }
        ctrls.width =dx
        ctrls.x = 0
    }


    function play() {
        if(camViewBar === null)
        {
            var ctrl = null
            for(var i=0; i< ctrls.children.length; i++) {
                ctrl = ctrls.children[i]
                var cx = ctrls.x + ctrl.x
                if((cx > 0) && (cx + ctrl.width < _root.width))
                    ctrl.play()
                else
                    ctrl.stop()
            }
        }
    }
    function pause() {
        var ctrl = null
        for(var i in ctrls.children) {
            ctrl = ctrls.children[i]
            var cx = ctrls.x + ctrl.x
            if((cx > 0) && (cx + ctrl.width < _root.width))
                ctrl.stop()
        }
    }
    function resume() {
        var ctrl = null
        for(var i in ctrls.children) {
            ctrl = ctrls.children[i]
            var cx = ctrls.x + ctrl.x
            if((cx > 0) && (cx + ctrl.width < _root.width))
                ctrl.resume()
        }
        //mnemo.showLines(true)
    }
    function stop() {
        for(var i in ctrls.children) {
            ctrls.children[i].stop()
        }
    }
}


