import QtQuick 2.4
import Trogl 1.0

LabelControl {
    id: _this
    width: _background.width
    height: _background.height
    property bool zVis: true
    property bool valid: obj?(obj.object.valid):false
    property string labelText: ""
    property var skin: Skin
    property color backgroundColor
    property color borderColor
    property color textColor

    property real radius: uiSettings.tvr
    property real tvaw: uiSettings.tvaw
    property real tvah: uiSettings.tvah
    property real borderWidth: uiSettings.tvb

    visible: zVis && valid

    onSkinChanged:
        _background.requestPaint()

    Canvas {
        id: _background
        width: Math.max(_text.paintedWidth + 2*radius, uiSettings.tvwc/1.4)
        height: Math.max(_text.paintedHeight + 2*radius + tvah, uiSettings.tvwc/1.4)

        onPaint: {
            var ctx = getContext("2d")
            var tvw = width;
            var tvh = height - tvah
            var hB = borderWidth*0.5
            ctx.clearRect(0, 0, width, height);
            ctx.fillStyle = Skin.temperatureLabelBackground
            ctx.strokeStyle = Skin.temperatureLabelBorder
            ctx.lineWidth = uiSettings.tvb;

            ctx.beginPath()
                ctx.moveTo(hB, radius)
                ctx.quadraticCurveTo(hB, hB, radius, hB)
                ctx.lineTo(width - radius - hB, hB)
                ctx.quadraticCurveTo(width - hB, hB, width - hB, radius)
                ctx.lineTo(width - hB, tvh-radius)
                ctx.quadraticCurveTo(width - hB, tvh, width-radius, tvh)
                ctx.lineTo((width+tvaw)/2, tvh)
                ctx.lineTo(width/2, height - hB)
                ctx.lineTo((width-tvaw)/2, tvh)
                ctx.lineTo(radius, tvh)
                ctx.quadraticCurveTo(hB, tvh, hB, tvh-radius)
            ctx.closePath()
            ctx.fill()
            ctx.stroke()
        }
    }

    Text {
        id: _text
        color: Skin.temperatureLabelText
        font.family: "Ubuntu"
        font.pointSize: uiSettings.tvfs
        text: labelText
        x: (_background.width - paintedWidth)/2
        y: (_background.height - uiSettings.tvah - paintedHeight)/2;
    }
    MouseArea {
        width: _background.width
        height: _background.height - tvah
        visible: obj?obj.active:false;
        onClicked: {if(obj) obj.labelClicked();}
    }
}
