import QtQuick 2.0
import "../TroglControls"
import "../"

Column {
    id: ccol
    property alias host: ipAddressInputText.text
    property alias port: ipPortInputText.text
    property alias pass: passwordInputText.text
    property Component ipKComponent: Qt.createComponent("qrc:/IpKeyboard.qml")
    property IpKeyboard ipBoard: null
    property Component portKComponent: Qt.createComponent("qrc:/PortKeyboard.qml")
    property PortKeyboard portBoard: null
    property Component findServerComponent: Qt.createComponent("qrc:/FindServerBar.qml")
    property FindServerBar findServerBar: null

    spacing: 10
    Text {
     color: Skin.preferencesBarSectionDivider
     font.family: "Ubuntu"
     font.pointSize: uiSettings.btm
     text: Langpack.barPreferencesTabProjectLabelServerHost
    }

    function ipOpen() {
        if(ipBoard == null)
        {
            ipBoard = ipKComponent.createObject(dynBarsContainer)
            ipBoard.done.connect(ipDone)
            ipBoard.closed.connect(ipClosed)
        }

        ipBoard.setHost(host)
        ipBoard.open()
    }
    function ipDone() {
        if(ipBoard)
        {
            host = ipBoard.ip()
            ipBoard.close()
        }
    }
    function ipClosed() {
        if(ipBoard)
            ipBoard.destroy()
    }

    function portOpen() {
        if(portBoard == null)
        {
            portBoard = portKComponent.createObject(dynBarsContainer)
            portBoard.done.connect(portDone)
            portBoard.closed.connect(portClosed)
        }

        portBoard.data = port
        portBoard.open()
    }
    function portDone() {
        if(portBoard)
        {
            port = portBoard.data
            portBoard.close()
        }
    }
    function portClosed() {
        if(portBoard)
            portBoard.destroy()
    }

    function findServerOpen() {
        if(findServerBar == null)
        {
            findServerBar = findServerComponent.createObject(dynBarsContainer)
            findServerBar.closed.connect(findServerClosed)
        }

        findServerBar.open()
    }
    function findServerClosed()
    {
        if(findServerBar)
        {
            if(findServerBar.host != "")
                host = findServerBar.host
            if(findServerBar.port != "")
                port = findServerBar.port
            findServerBar.destroy()
        }
    }

    Rectangle {
        id: ipAddressInput
        width: parent.width - ui.c*3 - ui.i*4
        height: uiSettings.b
        color: "#00000000"
        border.color: Skin.preferencesBarSectionDivider
        border.width: uiSettings.sf/4
        Text {
            id: ipAddressInputText
            anchors.fill: parent
            horizontalAlignment: TextInput.AlignHCenter
            verticalAlignment: TextInput.AlignVCenter
            color: Skin.preferencesBarTabName
            font.family: "Ubuntu"
            font.pointSize: uiSettings.btm
        }
        MouseArea {
            anchors.fill: parent
            onClicked: ipOpen()
        }

        Button_s1 {
            anchors.left: parent.right
            anchors.top: parent.top
            anchors.leftMargin: ui.i + ui.c
            height: ipAddressInput.height + ipPortInput.height + ccol.spacing*2 + portLabel.contentHeight
            img.source: "image://trogl/Search.svg"
            onClicked: findServerOpen()
        }

    }
    Text {
     id: portLabel
     color: Skin.preferencesBarSectionDivider
     font.family: "Ubuntu"
     font.pointSize: uiSettings.btm
     text: Langpack.barPreferencesTabProjectLabelServerPort
    }
    Rectangle {
        id: ipPortInput
        width: ipAddressInput.width
        height: uiSettings.b
        color: "#00000000"
        border.color: Skin.preferencesBarSectionDivider
        border.width: uiSettings.sf/4
        Text {
            id: ipPortInputText
            anchors.fill: parent
            horizontalAlignment: TextInput.AlignHCenter
            verticalAlignment: TextInput.AlignVCenter
            property int port: 0
            font.family: "Ubuntu"
            color: Skin.preferencesBarTabName
            font.pointSize: uiSettings.btm
            text: "55555"
        }
        MouseArea {
            anchors.fill: parent
            onClicked: portOpen()
        }
    }

    Rectangle {
        id: passwordInput
        width: parent.width
        height: uiSettings.b
        color: "#00000000"
        border.color: "#919191"
        border.width: uiSettings.sf/4
        visible: false
        TextInput {
            id: passwordInputText
            anchors.centerIn: parent
            property int port: 0
            color: "white"
            font.family: "Ubuntu"
            font.pointSize: uiSettings.btm
            text: "password"

            inputMask:  ""
        }
    }

    Component.onCompleted: {
        host = Global.projectServerHost()
        port = Global.projectServerPort()
        pass = Global.projectServerPassword()
    }
    function saveSettings() {
        Global.setProjectServer(host, parseInt(port), pass);
    }
}
