import QtQuick 2.4
import QtQuick.Window 2.2

Item {
    id: _control
    width: ui.c*4
    height: ui.c*2
    property alias model: c1.model
    property int current: -1
    property alias selected: c1.currentIndex
    property alias orientation: c1.orientation
    property alias layoutDidection: c1.layoutDirection
    property alias verticalLayoutDirection: c1.verticalLayoutDirection
    property color hiddenBG: "#00000000"

    Component.onCompleted: updateCurrentView()
    onCurrentChanged: updateCurrentView()
    signal finished(int index)

    function updateCurrentView() {
        var curItem = model.get(current)
        if(curItem)
        {
            text.text = curItem.caption
            img.source = curItem.url
        }
    }
    function showList()
    {
        c1.x = 0;
        c1.y = 0
        if(orientation === ListView.Vertical)
        {
            c1.width = _control.width
            c1.height = c1.contentHeight
            if(verticalLayoutDirection === ListView.BottomToTop)
                c1.y = - c1.height
            else
                c1.y = _control.height - c1.height
        }
        else
        {
            c1.width = c1.contentWidth
            c1.height = _control.height
            if(layoutDidection === ListView.RightToLeft)
                c1.x = _control.width - c1.width
        }
        c1.currentIndex = -1
        c1.visible = true
        background.color = Skin.ch
        mma.x = _control.childrenRect.x
        mma.y = _control.childrenRect.y
        mma.width = _control.childrenRect.width
        mma.height = _control.childrenRect.height
    }
    function hide()
    {
        mma.x = 0
        mma.y = 0
        mma.width = _control.width
        mma.height = _control.height
        c1.visible = false
        background.color = Skin.cv
        if(c1.currentIndex !== -1)
            finished(c1.currentIndex)
    }
    Rectangle {
        id: bg
        anchors.fill: _control
        color: Skin.cv
        opacity: 0.5
        visible: c1.visible
        radius: ui.c/8
    }
    Rectangle {
        id: background
        anchors.fill: parent
        color: Skin.cv
        opacity: 0.5
        radius: ui.c/8
    }
    Text {
        id: text
        font.family: "Ubuntu"
        font.bold: true
        style: Text.Normal
        color: Skin.cm
        anchors.centerIn: parent
    }
    TroglImage {
        id: img
        anchors.fill: parent
    }

    ListView {
        id: c1
        spacing: ui.i
        visible: false
        interactive: false
        model: ListModel{}
        onVisibleChanged: {
            bg.anchors.fill = visible?mma:_control
        }

        delegate: Button
        {
            backGround.opacity: 0.0
            bgNormal: "#00000000"
            width: _control.width
            height: _control.height
            text.text: (url===undefined)?"":caption
            text.color: Skin.cm
            img.source: url?url:""
            active: (_control.current === index)
        }
        highlightMoveVelocity: 1000000
        highlight: Rectangle {
            width: _control.width
            height: _control.height
            radius: ui.c/8
            color: Skin.ch
            opacity: 0.5
        }

        function select(mx, my) {
            var cPos = mapFromItem(mma, mx, my)
            if(verticalLayoutDirection === ListView.BottomToTop)
                cPos.y -= height
            if(layoutDidection === ListView.RightToLeft)
                cPos.x -= width
            var newInd = indexAt(cPos.x, cPos.y)
            currentIndex = indexAt(cPos.x, cPos.y)
            cPos = background.mapFromItem(mma, mx, my)
            background.color = background.contains(cPos)?Skin.ch:hiddenBG
        }
    }
    MouseArea {
        id: mma
        width: _control.width
        height: _control.height
        property bool forceClose: false
        onPressed: {
            forceClose = c1.visible
            showList();
            c1.select(mouseX, mouseY)
        }
        onMouseXChanged: c1.select(mouseX, mouseY)
        onMouseYChanged: c1.select(mouseX, mouseY)
        onReleased: {
            if(c1.currentIndex !== -1)
                hide()
        }
        onClicked: {
            if(forceClose)
            {
                c1.select(mouseX, mouseY)
                hide()
            }
        }
    }
}
