import QtQuick 2.4
import Trogl 1.0

Item {
    id: _Ctrl
    width: uiSettings.slw
    height: uiSettings.slsh
    visible: false
    property int mode: 0 //0-stop
                         //1 - up
                         //2 - down
                         //3 - left
                         //4 - right

    signal newMode(int nMode);

    onModeChanged: {
        switch (mode) {
            case 0://stop
                btn.x = (_Ctrl.width - btn.width)/2
                btn.y = (_Ctrl.height - btn.height)/2
                break;
            case 1://up
                btn.x = (_Ctrl.width - btn.width)/2
                btn.y = uiSettings.sld
                break;
            case 2://down
                btn.x = (_Ctrl.width - btn.width)/2
                btn.y = _Ctrl.height - btn.height - uiSettings.sld
                break;
        }
        newMode(mode);
    }

    Rectangle {
        id: bg
        anchors.fill: parent
        radius: uiSettings.slr
        color: Skin.shutterCtrlBackground
    }
    Image {
        source: "qrc:/Mechanics/shutters_arrow_up.svg"
        x: (bg.width - width)/2
        y: uiSettings.sld*2
        width: height*15/19
        height: uiSettings.sld*2
        sourceSize.width: width
        sourceSize.height: height
        fillMode: Image.PreserveAspectFit
    }
    Image {
        source: "qrc:/Mechanics/shutters_arrow_down.svg"
        x: (bg.width - width)/2
        y: bg.height - uiSettings.sld*2 - height
        width: height*15/19
        height: uiSettings.sld*2
        sourceSize.width: width
        sourceSize.height: height
        fillMode: Image.PreserveAspectFit
    }

    Rectangle {
        id: innborder
        width: parent.width - 2*uiSettings.sld
        height: parent.height - 2*uiSettings.sld
        anchors.centerIn: parent
        border.color: Skin.shutterCtrlBorder

        border.width: uiSettings.slcw
        color: "#00000000"
        radius: uiSettings.slri
    }

    Rectangle {
        id: btn
        x: (_Ctrl.width - btn.width)/2
        y: (_Ctrl.height - btn.height)/2
        width: uiSettings.slbw //innborder.width
        height:uiSettings.slbw// innborder.width
        radius: uiSettings.slrb
        gradient: Skin.shutterCtrlThumbBackground

        Image {
            source: "qrc:/Mechanics/shutters_pic.svg"
            anchors.centerIn: parent
            width: parent.width*0.3
            height: parent.height*0.5
            sourceSize.width: width
            sourceSize.height: height
            fillMode: Image.PreserveAspectFit
        }
    }

    function open(mouseX, mouseY) {
        _Ctrl.x = mouseX - _Ctrl.width/2
        _Ctrl.y = mouseY - _Ctrl.height/2
        _Ctrl.visible = true
        mode = 0;
    }

    function updatePos(pt)
    {
        if(Math.abs(pt.x - _Ctrl.width/2) < btn.width/2)
        {
            if(pt.y < btn.height)
                mode = 1
            else
            if(pt.y > _Ctrl.height - btn.height)
                mode = 2
            else
            if(Math.abs(pt.y - _Ctrl.height/2) < btn.height/2)
                mode = 0
        }
    }

    function released(pt)
    {
        visible = false
    }
    function moved(pt)
    {
        pt.x -= _Ctrl.x
        pt.y -= _Ctrl.y
        updatePos(pt)
    }

}

