import QtQuick 2.4
import Trogl 1.0

Item{
    id: _Slider
    width: uiSettings.slbw
    height: uiSettings.slbh
    property real minVal: 0
    property real maxVal: 100
    property real curVal: 0

    property int positionCount: 101;
    property int lowerLimit: 0;
    property int upperLimit: 100;

    onCurValChanged: {
        curVal = Math.max(Math.min(curVal, maxVal), minVal)
        updateThumbPos()
    }
    onMinValChanged: updateRange()
    onMaxValChanged: updateRange()

    function updateRange() {
        minVal = Math.min(minVal, maxVal)
        maxVal = Math.max(minVal, maxVal)
        curVal = Math.min(Math.max(curVal, minVal), maxVal)
    }

    function valFromY(newY)
    {
        var progress = 1.0 - (newY - tumb.height*0.5) / (workspace.height - tumb.height);
        var newVal =  Math.ceil((positionCount-1)*progress);
        newVal = minVal + (maxVal-minVal)*newVal/(positionCount-1)
        if((curVal <= upperLimit) && (newVal > upperLimit))
            curVal = upperLimit;
        else
            curVal = newVal;

    }
    function updateThumbPos(){
        tumb.y = ((workspace.height - tumb.height)*(1.0 - (curVal - minVal)/(maxVal - minVal))).toFixed()
    }
    property Rectangle background: Rectangle  {
        anchors.fill: parent
        color: "#00000000"
    }

    property Item workspace: Rectangle {
        anchors.fill: parent
        radius: tumb.radius
        color: "#00000000"
        border.width: uiSettings.slcw
        border.color: Skin.sliderCtrlBorder
    }
    property Rectangle tumb: Rectangle {
        width: parent.width
        height: Math.max(workspace.height/(positionCount), workspace.height/6);
        radius: uiSettings.slrb
        gradient: Skin.sliderCtrlThumb
    }
    Component.onCompleted: {
        background.parent = _Slider
        background.anchors.fill = _Slider

        workspace.parent = _Slider
        tumb.parent = workspace
    }
}
